==> huaweicloudsdknat-3.0.53-py2.py3-none-any.whl: huaweicloudsdknat/v2/model/show_nat_gateway_dnat_rule_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowNatGatewayDnatRuleRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'dnat_rule_id': 'str'
    }

    attribute_map = {
        'dnat_rule_id': 'dnat_rule_id'
    }

    def __init__(self, dnat_rule_id=None):
        """ShowNatGatewayDnatRuleRequest - a model defined in huaweicloud sdk"""
        
        

        self._dnat_rule_id = None
        self.discriminator = None

        self.dnat_rule_id = dnat_rule_id

    @property
    def dnat_rule_id(self):
        """Gets the dnat_rule_id of this ShowNatGatewayDnatRuleRequest.

        DNAT规则的ID。

        :return: The dnat_rule_id of this ShowNatGatewayDnatRuleRequest.
        :rtype: str
        """
        return self._dnat_rule_id

    @dnat_rule_id.setter
    def dnat_rule_id(self, dnat_rule_id):
        """Sets the dnat_rule_id of this ShowNatGatewayDnatRuleRequest.

        DNAT规则的ID。

        :param dnat_rule_id: The dnat_rule_id of this ShowNatGatewayDnatRuleRequest.
        :type: str
        """
        self._dnat_rule_id = dnat_rule_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowNatGatewayDnatRuleRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdknat-3.0.81-py2.py3-none-any.whl: huaweicloudsdknat/v2/model/show_nat_gateway_dnat_rule_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowNatGatewayDnatRuleRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'dnat_rule_id': 'str'
    }

    attribute_map = {
        'dnat_rule_id': 'dnat_rule_id'
    }

    def __init__(self, dnat_rule_id=None):
        """ShowNatGatewayDnatRuleRequest - a model defined in huaweicloud sdk"""
        
        

        self._dnat_rule_id = None
        self.discriminator = None

        self.dnat_rule_id = dnat_rule_id

    @property
    def dnat_rule_id(self):
        """Gets the dnat_rule_id of this ShowNatGatewayDnatRuleRequest.

        DNAT规则的ID。

        :return: The dnat_rule_id of this ShowNatGatewayDnatRuleRequest.
        :rtype: str
        """
        return self._dnat_rule_id

    @dnat_rule_id.setter
    def dnat_rule_id(self, dnat_rule_id):
        """Sets the dnat_rule_id of this ShowNatGatewayDnatRuleRequest.

        DNAT规则的ID。

        :param dnat_rule_id: The dnat_rule_id of this ShowNatGatewayDnatRuleRequest.
        :type: str
        """
        self._dnat_rule_id = dnat_rule_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowNatGatewayDnatRuleRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
